#? Arquivo gerado a partir de racas.json

racas = [{'abilities': [{'description': 'Por milênios, anões aprendem desde cedo a '
                                'avaliar passagens e condições de muralhas e '
                                'portais.\n'
                                '\n'
                                'Por isso são capazes de detectar, mesmo que '
                                'não estejam analisando ativamente, com um '
                                'resultado de 1 em 1d6, anomalias em pedras, '
                                'como armadilhas em cavernas ou fossos '
                                'escondidos, ou com um resultado de 1-2 em 1d6 '
                                'caso estejam efetivamente procurando.\n',
                 'name': 'Mineradores'},
                {'description': 'Os anões são muito resistentes aos efeitos '
                                'que afetem seu corpo, recebendo um bônus de '
                                '+1 em qualquer teste de JPC.\n',
                 'name': 'Vigoroso'},
                {'description': 'São restritas para anões que podem usar '
                                'apenas armas médias e pequenas. Armas grandes '
                                'forjadas como um item racial anão são '
                                'consideradas armas médias para um anão.\n',
                 'name': 'Armas grandes'},
                {'description': 'Anões são inimigos naturais e disputam '
                                'território com orcs, ogros e hobgoblins e, '
                                'por isso, os ataques dos anões contra essas '
                                'criaturas são considerados ataques fáceis.\n',
                 'name': 'Inimigos'}],
  'access': 'complete',
  'alignment_tendency': 'ordeiro',
  'description': 'Honrados, perfeccionistas e reservados, os anões são '
                 'conhecidos não só pela sua peculiar aparência, mas sobretudo '
                 'pela forma como se relacionam com as outras raças e com a '
                 'sua própria história.\n'
                 '\n'
                 'De aparência robustas e rústica, corpulentos e com uma '
                 'inconfundível grande barba, anões vivem junto dos seus clãs '
                 'com as montanhas sobre suas cabeças, minerando, forjando, '
                 'reverenciando seus antepassados e comemorando com cerveja e '
                 'suas famosas bebidas fortes.\n'
                 '\n'
                 'Os Salões sob a Montanha, onde vivem isolados, são locais '
                 'sagrados e reverenciados por eles. Lá, adotam um estilo de '
                 'vida comedido, voltado ao trabalho, entrecortando o silêncio '
                 'apenas com suas canções de trabalho e suas frequentes '
                 'comemorações.\n'
                 '\n'
                 'São guiados pela honra e pelo sentimento de gratidão por '
                 'todos aqueles que ajudaram a construir o orgulho que sentem '
                 'das suas origens, quando lideraram a raça anã em feitos de '
                 'superação, conquista e guerra contra seus inimigos.\n'
                 '\n'
                 'Como bons tradicionalistas, colocam sua família, seu clã e '
                 'principalmente sua raça acima de todas as coisas, inclusive '
                 'de si mesmos e de suas vontades pessoais.\n'
                 '\n'
                 'Buscam honrar suas origens tentando demonstrar que são '
                 'dignos de fazer parte do que eles costumam chamar: povo '
                 'perfeito.\n'
                 '\n'
                 'Exímios forjadores, trabalham o metal à sua vontade. Não há '
                 'nada que eles não possam forjar, e não há nenhum objeto de '
                 'metal que não fique perfeito após um anão aplicar suas '
                 'técnicas ancestrais de metalurgia.\n'
                 '\n'
                 'Com pensamento lógico acurado, se destacam na engenharia, '
                 'nas construções, nos trabalhos pesados, mas, ao mesmo tempo, '
                 'demonstram pouca aptidão às artes arcanas.\n'
                 '\n'
                 'Fora de suas terras, se mostram orgulhosos e defensores de '
                 'suas origens, fazendo questão de sempre comparar tudo à '
                 'volta com a versão melhorada a qual os anões são capazes de '
                 'criar.\n'
                 '\n'
                 '# Personalidade\n'
                 '\n'
                 'Orgulho, tradição e obsessão são três importantes palavras '
                 'para descrever a personalidade anã.\n'
                 '\n'
                 'Orgulhosos de tudo relativo ao seu povo, estão a todo tempo '
                 'lembrando a todos da importância, da imponência, da '
                 'qualidade, da grandiosidade do seu povo, das canções que '
                 'glorificam as vitórias sobre seus inimigos.\n'
                 '\n'
                 'Um anão é quase um escravo dos feitos dos seus antepassados. '
                 'Um herói anão é, antes de tudo, uma régua de perfeição. Um '
                 'grau a admirar, perseguir e atingir.\n'
                 '\n'
                 'Tradição, para eles, não é uma mera forma de passar aos mais '
                 'novos os costumes de seu povo, e sim um estilo de vida e um '
                 'código de honra. Uma espécie de linha guia para basear suas '
                 'ações e seu pensamento.\n'
                 '\n'
                 'O anão é um ser obcecado. Pela defesa dos seus ideais, pelo '
                 'seu povo, pela perfeição do seu trabalho.\n'
                 '\n'
                 'Seja a excelência em batalha, o minucioso trabalho de forja '
                 'de armas e armaduras, a fermentação precisa da cerveja, a '
                 'composição da canção que zomba dos orcs, o ideal de vida do '
                 'anão está centrado na perfeição num nível próximo da '
                 'idolatria espiritual.\n'
                 '\n'
                 '# O Anão nas Aventuras\n'
                 '\n'
                 'Partir para as aventuras é mais do que uma opção para alguns '
                 'anões, sendo, em alguns casos, uma forma de reverenciar as '
                 'tradições do seu povo.\n'
                 '\n'
                 'Com uma memória repleta de feitos épicos e exemplos a '
                 'admirar e a seguir, provar-se capaz jogando-se no mundo é, '
                 'sem dúvida, o mais importante dos motivadores para um anão '
                 'aventurar-se.\n'
                 '\n'
                 'O anão quer provar sua capacidade, sua habilidade, '
                 'resiliência e ser digno de portar o nome de seu clã.\n'
                 '\n'
                 'Anões aventureiros são guiados pelo exemplo e pelo orgulho '
                 'dos feitos os quais podem realizar e que deixarão para as '
                 'futuras gerações.\n'
                 '\n'
                 '## Perguntas para se responder ao criar um anão:\n'
                 '\n'
                 '* **Pergunta 1:** _Do que seu anão mais se orgulha das suas '
                 'tradições?_\n'
                 '* **Pergunta 2:** _O que seu anão busca provar ou '
                 'realizar?_\n'
                 '* **Pergunta 3:** _O que seu anão possui como principal '
                 'obsessão?_\n',
  'flavor': 'Orgulhosos Habitantes dos Salões sob a Montanha.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 22},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'id': 'anao',
  'infravision': 18,
  'movement': 6,
  'name': 'Anão',
  'picture': 'https://public.olddragon.com.br/7s1vfmhibfsow0rp1hhb7358cpch',
  'thumb_picture': 'https://public.olddragon.com.br/1xeonp73mssl5zdlhyubhzhwytqn',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/anao.json'},
 {'access': 'limited',
  'flavor': 'Reclusos Engenheiros dos Picos e Guardiões da Tradição Anã.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-jogador.json',
              'page': 6}],
  'id': 'anao-das-montanhas',
  'name': 'Anão das Montanhas',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/anao-das-montanhas.json'},
 {'access': 'limited',
  'flavor': 'Mestres das Forjas Antigas e Senhores dos Veios Esquecidos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-jogador.json',
              'page': 6}],
  'id': 'anao-das-profundezas',
  'name': 'Anão das Profundezas',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/anao-das-profundezas.json'},
 {'abilities': [{'description': 'A forma como as casas élficas são '
                                'construídas, respeitando a forma natural das '
                                'árvores e abrigos, dá aos elfos uma percepção '
                                'especial no que diz respeito a portas e '
                                'passagens não convencionais e até mesmo '
                                'secretas.\n'
                                '\n'
                                'Ao passarem a até 6 metros de uma porta '
                                'secreta, mesmo que não a estejam procurando, '
                                'os elfos podem detectá-la com um resultado 1 '
                                'em 1d6, ou com um resultado de 1-2 em 1d6 '
                                'caso estejam efetivamente procurando pela '
                                'porta secreta.\n',
                 'name': 'Percepção Natural'},
                {'description': 'Os elfos controlam com precisão seus '
                                'movimentos no espaço ao redor do seu corpo, '
                                'recebendo um bônus de +1 em qualquer teste de '
                                'JPD.\n',
                 'name': 'Graciosos'},
                {'description': 'Os elfos possuem familiaridade com o '
                                'arqueirismo, o qual consideram uma arte '
                                'marcial, recebendo um bônus de +1 nos danos '
                                'causados em seus ataques à distância com os '
                                'arcos.\n',
                 'name': 'Arma Racial'},
                {'description': 'Os elfos são imunes a efeitos ou magias que '
                                'envolvam sono e também contra a paralisação '
                                'causada por um Ghoul.\n',
                 'name': 'Imunidades'}],
  'access': 'complete',
  'alignment_tendency': 'neutro',
  'description': 'Os elfos são das mais longevas raças encontradas nos mundos '
                 'de fantasia e a sua relação com o tempo doutrina boa parte '
                 'das suas características, personalidade e a forma como as '
                 'outras raças os enxergam e se relacionam com eles.\n'
                 '\n'
                 'Fisicamente são esguios e até um pouco franzinos se '
                 'comparados a um humano, além de ligeiramente mais baixos. '
                 'Seus cabelos, compridos para machos e fêmeas, estão sempre '
                 'penteados, adornados com acessórios e podem ser encontrados '
                 'em praticamente todas as cores.\n'
                 '\n'
                 'A característica física mais marcante de um elfo está nas '
                 'suas orelhas – pontudas e longas –, muito embora o traço dos '
                 'seus olhos – amendoados, delicados e levemente alongados – '
                 'seja uma característica igualmente marcante.\n'
                 '\n'
                 'A relação do elfo com o tempo dita sua forma de pensar e '
                 'agir. Como frequentemente atingem 1.000 anos de vida, elfos '
                 'se sentem compelidos a ocuparem suas vidas com o que mais '
                 'valorizam como a dança, a música, a esgrima, o arqueirismo e '
                 'a magia arcana.\n'
                 '\n'
                 'Isso pode fazer as pessoas acreditarem que Elfos são '
                 'distantes ou, de certa forma, um pouco fúteis. Um erro comum '
                 'cometido pelos observadores menos atentos.\n'
                 '\n'
                 'Outra característica dos elfos, sobretudo os que estão fora '
                 'da sua terra, é a distância, dando-lhes uma certa '
                 'característica de frieza e até prepotência. Por se '
                 'considerarem estranhos fora de suas fronteiras, possuem '
                 'dificuldade de se envolver nos problemas das outras raças, '
                 'refletindo na dificuldade de criar laços de amizade.\n'
                 '\n'
                 'No entanto, quando um elfo é conquistado como amigo, a '
                 'amizade se mostrará duradoura. A amizade de um elfo dura '
                 'mais do que muitas vidas, costumam dizer os humanos os quais '
                 'puderam provar desse relacionamento. Vivendo tantos séculos, '
                 'esta é uma verdade incontestável.\n'
                 '\n'
                 '# Personalidade\n'
                 '\n'
                 'Viver tanto tempo molda a personalidade de um elfo. O ritmo '
                 'do tempo é excepcional para um elfo. As mudanças ocorrem tão '
                 'depressa que se tornam complicadas de seguir, então, para '
                 'que se importar? Melhor é focar na qualidade e não na '
                 'quantidade. Se 100 espadas medianas podem ser '
                 'confeccionadas, um elfo prefere gastar o mesmo tempo numa '
                 'única peça exemplar em qualidade e perfeição.\n'
                 '\n'
                 'Com tanto tempo disponível para aprender tantas coisas, '
                 'desperdiçar tempo seria uma opção bem óbvia, mas aí se '
                 'esconde uma grandeza da sua raça. Ao contrário do que possa '
                 'parecer, elfos gostam de coisas bem-feitas e duradouras, '
                 'assim como eles. Serviço bem-feito é sempre aquele com a '
                 'maior duração.\n'
                 '\n'
                 'Essa relação entre qualidade, tempo e perfeição molda todo o '
                 'pensamento élfico e a construção da sua personalidade.\n'
                 '\n'
                 '# O Elfo nas Aventuras\n'
                 '\n'
                 'Apesar de bem mais raros que os humanos, elfos não são '
                 'aventureiros improváveis. A fome por conhecimento, desejo '
                 'por viajar, a vontade de provar-se para os seus como um elfo '
                 'exemplar e, principalmente, o tempo disponível, são as '
                 'principais forças a empurrar um elfo para a vida '
                 'aventureira.\n'
                 '\n'
                 'As coisas mudam tão rapidamente que acompanhar as mudanças, '
                 'ou mesmo fazer parte destas mudanças, pode ser uma '
                 'interessante força motriz para eles.\n'
                 '\n'
                 'Eles querem acompanhar o que acontece, se aperfeiçoarem e se '
                 'provarem como capazes.\n'
                 '\n'
                 'Elfos são aventureiros observadores que querem entender o '
                 'mundo onde vivem.\n'
                 '\n'
                 '## Perguntas para se responder ao criar um elfo:\n'
                 '\n'
                 '* **Pergunta 1:** _O que seu elfo busca provar? Para si ou '
                 'para seus iguais?_\n'
                 '* **Pergunta 2:** _O que seu elfo pensa sobre estar com '
                 'outras raças?_\n'
                 '* **Pergunta 3:** _O que seu elfo sente por estar longe de '
                 'sua terra?_\n',
  'flavor': 'Misteriosos, Longevos e Graciosos habitantes das Florestas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 20},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'id': 'elfo',
  'infravision': 18,
  'movement': 9,
  'name': 'Elfo',
  'picture': 'https://public.olddragon.com.br/0bkgjun19spomx5ulu8epfe6l4ca',
  'thumb_picture': 'https://public.olddragon.com.br/1j3zcqmw25sqoy8wlduncxjihagw',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/elfo.json'},
 {'access': 'limited',
  'flavor': 'Guardião da Tradição, da Magia e do Orgulho Élfico.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-jogador.json',
              'page': 7}],
  'id': 'elfo-cinzento',
  'name': 'Elfo Cinzento',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/elfo-cinzento.json'},
 {'access': 'limited',
  'flavor': 'Filhos da Floresta, Livres, Fortes e Instintivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-jogador.json',
              'page': 7}],
  'id': 'elfo-silvestre',
  'name': 'Elfo Silvestre',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/elfo-silvestre.json'},
 {'abilities': [{'description': 'Precisos, gnomos possuem a habilidade de '
                                'conhecer o real valor de objetos de arte, '
                                'gemas, joias ou outros objetos de luxo '
                                'finamente trabalhados, possuindo 1-4 chances '
                                'em 1d6 de acertar o valor real do item.\n'
                                '\n'
                                'Se o resultado for um 5, a avaliação se dará '
                                '25% abaixo do valor real, se for um 6, será '
                                '25% acima do valor real. Este teste deve ser '
                                'realizado, em segredo, pelo Mestre.\n',
                 'name': 'Avaliadores'},
                {'description': 'Os gnomos são muito espertos e desconfiados, '
                                'além de vigorosos contra efeitos negativos '
                                'que afetem sua mente e corpo, assim, podem '
                                'escolher entre receber um bônus de +1 em uma '
                                'das duas jogadas de proteção, JPC ou JPS.\n',
                 'name': 'Sagazes e Vigorosos'},
                {'description': 'Por serem pequenos, mas mineradores e '
                                'forjadores, gnomos não possuem restrições em '
                                'relação a armaduras, mas precisam adquiri-las '
                                'junto a comunidades de sua raça.\n'
                                '\n'
                                'Entretanto, um gnomo não pode usar armas '
                                'grandes, sendo restrito apenas a armas '
                                'pequenas ou médias. Um gnomo só consegue usar '
                                'uma arma média como se fosse uma arma de duas '
                                'mãos.\n',
                 'name': 'Restrições'}],
  'access': 'complete',
  'alignment_tendency': 'neutro',
  'description': 'Gnomos são parentes distantes dos anões, sendo um pouco mais '
                 'baixos e de aparência mais rústica.\n'
                 '\n'
                 'O nariz se destaca pelo tamanho grande e pelo formato '
                 'arredondado, uma espécie de símbolo do orgulho racial.\n'
                 '\n'
                 'A pele dos gnomos é sempre enrugada, morena e bronzeada com '
                 'tons terrosos e vermelhos escuros. Os cabelos são brancos, '
                 'platinados e claros, fazendo os humanos acreditarem que '
                 'todos os gnomos são velhos.\n'
                 '\n'
                 'Outra característica racial famosa é o uso do específico '
                 'chapéu de feltro, cônico, alto e pontudo, sempre de cores '
                 'fortes ligadas às suas famílias. Gnomos aventureiros '
                 'frequentemente abrem mão do chapéu em favor da praticidade, '
                 'mas nas suas terras e em momentos de paz, o chapéu pontudo '
                 'sempre estará em uso.\n'
                 '\n'
                 'São conhecidos pelo bom humor e o apreço pelas boas piadas, '
                 'bem como objetos finamente trabalhados, como joias e gemas.\n'
                 '\n'
                 'Estas últimas geram uma verdadeira obsessão entre os gnomos, '
                 'pois são conhecidos como habilidosos joalheiros e '
                 'lapidadores, fazendo deles ótimos avaliadores de gemas e '
                 'joias.\n'
                 '\n'
                 'Vivem em ambientes isolados nas colinas, em suas comunidades '
                 'sem muita aproximação com povoados de outras raças. Há uma '
                 'certa desconfiança nutrida pelo povo alto, como são chamados '
                 'os elfos e humanos.\n'
                 '\n'
                 'Muito dificilmente esta desconfiança evoluirá para a '
                 'hostilidade, a verdade é que gnomos são reservados, '
                 'preferindo viver mais afastados em suas cidades nas colinas, '
                 'construídas sempre em torno de suas minas.\n'
                 '\n'
                 'A mina é o ponto central da comunidade dos gnomos. Onde os '
                 'anões escavam a pedra, os gnomos escavam a terra. Se anões '
                 'procuram aço e outros metais para forjar, gnomos se '
                 'preocupam mais com metais brilhosos e valiosos. Tais metais '
                 'almejados pelos gnomos são usados por estes para a '
                 'fabricação de joias e gemas.\n'
                 '\n'
                 '# Personalidade\n'
                 '\n'
                 'Quando à vontade, são festeiros, divertidos e galhofeiros, '
                 'donos de um senso de humor sem igual. Caso contrário, são '
                 'arredios, desconfiados e calados.\n'
                 '\n'
                 'Essa dicotomia define o gnomo, fazendo dele uma incógnita '
                 'para quem não conhece sua forma de agir: uma curiosa mistura '
                 'entre um ser obstinado e calculista que sabe a hora certa de '
                 'agir.\n'
                 '\n'
                 'Curioso porque possuem uma inata vontade de entender o '
                 'funcionamento das coisas. Seja um material ou mecanismo, os '
                 'gnomos precisam entender como funciona. Precisa fazer '
                 'sentido pra eles.\n'
                 '\n'
                 'E aí entra a obstinação. Gnomos não são dados a '
                 'desistências. Quando enfiam algo na cabeça, farão assim que '
                 'conseguirem.\n'
                 '\n'
                 'Mas não com a teimosia irritante dos anões que pode fazer '
                 'com que fiquem cegos sem entender o risco que estão '
                 'sofrendo. Os gnomos sabem esperar, mas não se esquecerão do '
                 'que precisam fazer. Na primeira oportunidade segura '
                 'encontrada... Lá estará o gnomo.\n'
                 '\n'
                 '# O Gnomo nas Aventuras\n'
                 '\n'
                 'Os gnomos possuem alguns gatilhos que os empurram para o '
                 'mundo das aventuras e, assim como os halflings, a '
                 'curiosidade pelo mundo lá fora é uma das mais frequentes, '
                 'mas não a única.\n'
                 '\n'
                 'Certamente gnomos abandonam a pacificidade de sua terra para '
                 'compreender o mundo ao seu redor e, claro, por motivos mais '
                 'mundanos como acumular riquezas, ver o que está acontecendo '
                 'e se expor aos riscos.\n'
                 '\n'
                 'E quando isso vira uma obstinação, a estrada é o único '
                 'caminho o qual eles podem trilhar.\n'
                 '\n'
                 'Gnomos gostam de participar, gostam de estar no teatro dos '
                 'acontecimentos. Contar como o Dragão Velho foi morto é pouco '
                 'para ele.\n'
                 '\n'
                 'O ideal é que o gnomo possa dizer como ELE ajudou a matar o '
                 'Dragão Velho e, principalmente, como ele hoje ostenta todas '
                 'aquelas maravilhosas joias roubadas do covil do Dragão '
                 'Velho.\n'
                 '\n'
                 '## Perguntas para se responder ao criar um aventureiro '
                 'gnomo:\n'
                 '\n'
                 '* **Pergunta 1:** _O que é o principal motivador da '
                 'obstinação de seu gnomo?_\n'
                 '* **Pergunta 2:** _Sua vida pré-aventuras foi divertida ou '
                 'ele achava tudo enfadonho nas minas?_\n'
                 '* **Pergunta 3:** _Qual é o tipo de humor dele? Prega peças '
                 'ou prefere os comentários espirituosos?_\n',
  'flavor': 'Os desconfiados, mas galhofeiros, habitantes de minas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 16},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'id': 'gnomo',
  'infravision': 18,
  'movement': 6,
  'name': 'Gnomo',
  'picture': 'https://public.olddragon.com.br/lv8uumgckkuzz2xu1odv88zj4fzj',
  'thumb_picture': 'https://public.olddragon.com.br/o8oqru6krhzlesjnnn5zbebdcwid',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/gnomo.json'},
 {'access': 'limited',
  'flavor': 'Reclusos Sábios das Árvores, Vozes Amigas da Natureza.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-jogador.json',
              'page': 8}],
  'id': 'gnomo-das-florestas',
  'name': 'Gnomo das Florestas',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/gnomo-das-florestas.json'},
 {'abilities': [{'description': 'O formato de seus pés os tornam perfeitos '
                                'escaladores, conseguindo escalar com uma '
                                'chance de 1-2 em 1d6. Se o Grizzi adotar a '
                                'classe Ladrão, ele acrescenta ainda um bônus '
                                'de 1 no seu talento Escalar.',
                 'name': 'Escaladores'},
                {'description': 'Um grizzi que conseguir passar uma rodada '
                                'completa xingando um alvo, faz com que na '
                                'rodada seguinte este alvo realize todos os '
                                'testes como se fossem testes difíceis.',
                 'name': 'Exasperar'},
                {'description': 'Devido à baixa estatura e agilidade, todos os '
                                'ataques provenientes de criaturas grandes ou '
                                'maiores são considerados ataques difíceis '
                                'para acertar um Grizzi.',
                 'name': 'Pequenos'},
                {'description': 'Por não terem tradição na forja de armaduras, '
                                'os Grizzis usam apenas armaduras de couro, a '
                                'não ser que a armadura seja confeccionada '
                                'especialmente para ele.\n'
                                '\n'
                                'Um grizzi não pode usar armas grandes, sendo '
                                'restrito apenas a armas pequenas ou médias. '
                                'Um Grizzi só consegue usar uma arma média '
                                'como se fosse uma arma de duas mãos.\n',
                 'name': 'Restrições'}],
  'access': 'complete',
  'alignment_tendency': 'caotico',
  'description': 'Grizzis são pequenos humanoides de Ryanon, de grande '
                 'inteligência e criatividade. A maioria dessa raça é composta '
                 'de indivíduos de natureza pacata, rural e pouco dados a '
                 'assuntos bélicos.\n'
                 '\n'
                 'São colecionadores compulsivos de qualquer coisa que lhes '
                 'suscite a obsessão, e possuem uma cultura rica e costumes '
                 'exóticos.\n'
                 '\n'
                 'Seu físico é sua principal característica.\n'
                 '\n'
                 'Possuem a pele clara, em tons que podem ir do branco ao '
                 'mostarda e repleta de rugas e verrugas, grandes olhos '
                 'expressivos e esbugalhados e orelhas pontudas voltadas para '
                 'trás. Suas mãos possuem 3 dedos (um polegar e dois '
                 '"indicadores") e seus pés, também com três dedos '
                 'articulados, se assemelham muito mais a uma mão que um pé '
                 'humano.\n'
                 '\n'
                 'Costumam viver e se desenvolver exatamente como os humanos. '
                 'Por volta dos 15 anos, porém, adquirem a aparência de jovens '
                 '"idosos" com cabelos ralos, brancos e pele enrugada. '
                 'Aparência que se manterá pelos próximos 50 a 60 anos, quando '
                 'sua figura começará a envelhecer ainda mais.\n'
                 '\n'
                 'Gostam de habitar comunidades tranquilas, longe do tumulto '
                 'das grandes e ruidosas cidades humanas. Estão quase sempre '
                 'próximas de pequenas florestas ou bosques, onde costumam '
                 'coletar frutas e produzir os famigerados repolhos pretos '
                 'para o gulash.\n'
                 '\n'
                 'Todo Grizzi recebe dos pais, logo ao nascer, uma árvore '
                 'plantada em algum bosque próximo. A esta árvore é dado o '
                 'nome de "zerele". Cada zerele pertence ao indivíduo em '
                 'específico e adquire status de símbolo sagrado para a '
                 'comunidade.\n'
                 '\n'
                 '# Personalidade\n'
                 '\n'
                 'Apesar de serem pouco amigáveis à princípio, não compactuam '
                 'com a falta de cordialidade e violência gratuita. Você '
                 'jamais verá um Grizzi chamando alguém para briga '
                 'gratuitamente.\n'
                 '\n'
                 'Grizzis podem ser considerados os seres mais mal-humorados '
                 'de toda Ryanon, especialmente depois de acordar. Grizzis são '
                 'pessimistas; para eles, tudo sempre dará errado da pior '
                 'forma possível, e todo dia é o pior das suas vidas.\n'
                 '\n'
                 'São tão pessimistas que o famoso matemático grizzi de nome '
                 'Märphy Galanos estabeleceu que "se algo possui uma mínima '
                 'chance de dar errado, certamente dará errado, e dará errado '
                 'de novo se você for um Grizzi".\n'
                 '\n'
                 'Outra marca registrada dos grizzi é a habilidade de xingar. '
                 'Usando adjetivos pouco comuns e até estranhos, aliados a '
                 'palavras de baixo calão, os Grizzis conseguem ofender uns '
                 'aos outros com grande intensidade.\n'
                 '\n'
                 'Colecionar é a razão principal de viver de todo Grizzi. Eles '
                 'acreditam piamente que quando morrem vão para uma terra '
                 'vazia sem cor onde as únicas coisas que poderão carregar são '
                 'suas coleções, que chamam de "menish".\n'
                 '\n'
                 'Assim, colecionar não é apenas religião, é o meio de '
                 'garantir uma eternidade menos tediosa. E eles escolhem '
                 'coisas inabituais para colecionar, mesmo dentes incisivos de '
                 'orcs ou lascas de unhas de dedão de monstros encontrados '
                 'pelo caminho.\n'
                 '\n'
                 'O amor pelas coleções é tamanho, que um Grizzi e todas as '
                 'suas coleções serão enterrados aos pés da sua _zerele_ a sua '
                 'árvore pessoal, para passarem juntos e segundo suas crenças, '
                 'continuarem colecionando por toda a eternidade.\n'
                 '\n'
                 '# O Grizzi nas Aventuras\n'
                 '\n'
                 'Grizzis não são à primeira vista, aventureiros natos. Sua '
                 'vida pacata, seus gostos pouco ortodoxos e sua imensa '
                 'vontade de permanecer quieto, colecionando e reclamando da '
                 'vida, fazem das aventuras algo pouco atrativo para um Grizzi '
                 'padrão.\n'
                 '\n'
                 'No entanto, quando o chamado da aventura surge para um '
                 'Grizzi, ele não pensa duas vezes. Afinal, esta é a '
                 'oportunidades perfeita de colecionar coisas diferentes, de '
                 'lugares inimagináveis.\n'
                 '\n'
                 '## Perguntas para se responder ao criar um Grizzi:\n'
                 '\n'
                 '* **Pergunta 1:** _O que seu grizzi coleciona?_\n'
                 '* **Pergunta 2:** _O que seu grizzi não encontrou na sua '
                 'vida e que o levou a se aventurar?_\n'
                 '* **Pergunta 3:** _O que seu grizzi mais despreza nas '
                 'pessoas a ponto de ser algo impossível de tolerar sem uma '
                 'boa dose de rabugice?_\n',
  'flavor': 'Os aventureiros mais irritantemente criativos de Kadur.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao.json',
              'page': None},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao-od2.json',
              'page': None}],
  'id': 'grizzi',
  'infravision': 0,
  'movement': 6,
  'name': 'Grizzi',
  'picture': 'https://public.olddragon.com.br/rl9m2qrz527kgbk6yisw96uynabr',
  'thumb_picture': 'https://public.olddragon.com.br/8zeiibty4h6qxv8ak3n62c6071ao',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/grizzi.json'},
 {'abilities': [{'description': 'São especialistas em se esconder e em passar '
                                'despercebidos, conseguindo se esconder com '
                                'uma chance de 1-2 em 1d6. Se o Halfling '
                                'adotar a classe Ladrão, ele acrescenta ainda '
                                'um bônus de 1 no seu talento Furtividade.\n',
                 'name': 'Furtivos'},
                {'description': 'Os halflings são muito resistentes a efeitos '
                                'que afetem sua força de vontade, recebendo um '
                                'bônus de +1 em qualquer teste de JPS.\n',
                 'name': 'Destemidos'},
                {'description': 'Pela tradição racial de jogos de arremesso, '
                                'para os halflings qualquer ataque à distância '
                                'com uma arma de arremesso é considerado um '
                                'ataque fácil.\n',
                 'name': 'Bons de Mira'},
                {'description': 'Devido à baixa estatura e agilidade, todos os '
                                'ataques provenientes de criaturas grandes ou '
                                'maiores são considerados ataques difíceis '
                                'para acertar um halfling.\n',
                 'name': 'Pequenos'},
                {'description': 'Por não terem tradição na forja de armaduras, '
                                'os halflings usam apenas armaduras de couro, '
                                'a não ser se armadura for confeccionada '
                                'especialmente para ele.\n'
                                '\n'
                                'Um halfling não pode usar armas grandes, '
                                'sendo restrito apenas a armas pequenas ou '
                                'médias. Um halfling só consegue usar uma arma '
                                'média como se fosse uma arma de duas mãos.\n',
                 'name': 'Restrições'}],
  'access': 'complete',
  'alignment_tendency': 'neutro',
  'description': 'Pequenos, roliços, metódicos e corajosos, os halflings são '
                 'um povo pacífico e rural habitando as colinas verdejantes, '
                 'vivendo do que plantam e criam, formando comunidades '
                 'bucólicas e pequenas, quase sempre próximas às fronteiras '
                 'das terras dos humanos.\n'
                 '\n'
                 'Possuem uma aparência muito similar a dos humanos, como se '
                 'fossem mini-homens. Suas orelhas levemente pontiagudas, mas '
                 'não o suficiente para se parecerem com as dos elfos, se '
                 'destacam juntamente de seus pés, os quais são grandes, '
                 'robustos e cobertos com uma espessa cobertura de pelos '
                 'desgrenhados. Halflings estão, quase sempre, descalços.\n'
                 '\n'
                 'Suas feições são bonachonas, com bochechas grandes brilhosas '
                 'e rosadas, seus cabelos são encaracolados, grossos e '
                 'volumosos, como se tivessem sido penteados '
                 'despretensiosamente com as mãos.\n'
                 '\n'
                 'São trabalhadores eficientes e metódicos. Buscam realizar '
                 'suas tarefas com disciplina e correção para poderem '
                 'desfrutar daquilo que mais gostam: o ócio regado a doses '
                 'cavalares de conforto.\n'
                 '\n'
                 'Gostam de viver bem, de comer com fartura, contar histórias '
                 'exageradamente longas e de humor duvidoso. Apesar disso, são '
                 'bons companheiros, sempre amigáveis, se você não se importar '
                 'com histórias intermináveis e piadas com pouco sentido.\n'
                 '\n'
                 'O ideal de vida dos Halflings é viver em paz e sob o signo '
                 'da calma, trabalhar diariamente, descansar à beira do rio, '
                 'ler, comer (de preferência 6 refeições por dia) e ver o '
                 'tempo passar, em paz, na tranquilidade e longe da correria e '
                 'das preocupações.\n'
                 '\n'
                 'Se o conforto é o objeto de desejo de um halfling, outra '
                 'característica é importante para defini-los: a curiosidade.\n'
                 '\n'
                 'Halflings sentem um magnetismo com coisas que não conhecem e '
                 'com assuntos que não dominam. Um halfling explora, '
                 'investiga, toca. As lendas e histórias de locais distantes e '
                 'de terras desconhecidas aliadas ao seu conhecido destemor, '
                 'são uma das poucas coisas capazes de fazê-los abandonar suas '
                 'tocas e um bom livro à beira da lareira.\n'
                 '\n'
                 'Tolerantes, estáveis e sociáveis, os halflings são sem '
                 'dúvida os amigos mais fáceis de se fazer, fora de um '
                 'indivíduo de sua própria raça.\n'
                 '\n'
                 '# Personalidade\n'
                 '\n'
                 'Se estabilidade é o adjetivo do halfling, a curiosidade é a '
                 'contradição que os define. Vivendo em constante conflito '
                 'entre comodidade e curiosidade, halflings têm “contradição” '
                 'como nome do meio.\n'
                 '\n'
                 'Contradição a qual se une a outra igualmente intrigante: a '
                 'questão ambição-riqueza. Não que eles não se importem com '
                 'dinheiro, sim, eles se importam, mas, se para outras raças '
                 'dinheiro é poder, para os halflings dinheiro é conforto e '
                 'tranquilidade.\n'
                 '\n'
                 'Uma cadeira estofada com tecido confortável, ideal para uma '
                 'sesta após uma das muitas refeições diárias, faz mais a '
                 'cabeça de um halfling do que um trono cravejado de gemas '
                 'preciosas.\n'
                 '\n'
                 'Ao mesmo tempo, halflings não possuem um forte desejo de '
                 'acúmulo e ambições por poder. Você dificilmente verá um '
                 'halfling ostentando riqueza ou divagando sobre conquistas '
                 'políticas. Eles são muito mais práticos nos seus desejos: a '
                 'sensação de pertencimento, a vida em comunidade, as '
                 'amizades, o conforto, as viagens ao desconhecido, tudo isso '
                 'temperado com uma boa dose de destemor.\n'
                 '\n'
                 '# O Halfling nas Aventuras\n'
                 '\n'
                 'Halflings precisam de poucos motivos para se tornarem '
                 'aventureiros, como sua curiosidade e seu destemor.\n'
                 '\n'
                 'Já suas buscas podem ser bem mais variadas. Podem estar indo '
                 'atrás de um remédio para o tédio, de diversão ou de uma boa '
                 'história para contar. Os clássicos literários dos halflings '
                 'quase sempre descrevem aventuras, heróis e seus feitos e, em '
                 'menor número, biografias de halflings aventureiros com uma '
                 'boa dose de exagero (ou não).\n'
                 '\n'
                 'Halflings se aventuram porque querem expandir seus '
                 'horizontes, e não têm nenhum medo do desconhecido.\n'
                 '\n'
                 'Eles querem conhecer, ocupar-se, entender e participar.\n'
                 '\n'
                 '## Perguntas para se responder ao criar um halfling:\n'
                 '\n'
                 '* **Pergunta 1:** _O que seu halfling sentiu quando decidiu '
                 'se aventurar?_\n'
                 '* **Pergunta 2:** _O que seu halfling busca enquanto se '
                 'aventura?_\n'
                 '* **Pergunta 3:** _O que seu halfling planeja fazer com o '
                 'que ganhar quando se aposentar?_\n',
  'flavor': 'Os mais Perspicazes e Curiosos Aventureiros.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 24},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'id': 'halfling',
  'infravision': 0,
  'movement': 6,
  'name': 'Halfling',
  'picture': 'https://public.olddragon.com.br/t7nwkll1zaxtorirhh6palz12lkz',
  'thumb_picture': 'https://public.olddragon.com.br/flrpr5qlgdp2id1ubp02vzo4ygzl',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/halfling.json'},
 {'access': 'limited',
  'flavor': 'Trabalhadores Incansáveis e Companheiros de Mineração.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-jogador.json',
              'page': 7}],
  'id': 'halfling-robusto',
  'name': 'Halfling Robusto',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/halfling-robusto.json'},
 {'access': 'limited',
  'flavor': 'Viajantes Ágeis e Curiosos das Colinas Arborizadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-jogador.json',
              'page': 8}],
  'id': 'halfling-tipossalto',
  'name': 'Halfling Tipossalto',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/halfling-tipossalto.json'},
 {'abilities': [{'description': 'Humanos aprendem tudo o que se propõem a '
                                'fazer de forma muito mais rápida que as '
                                'outras raças. Com isso, um humano recebe um '
                                'bônus de 10% sobre toda experiência (XP) '
                                'recebida.\n',
                 'name': 'Aprendizado'},
                {'description': 'Os humanos são muito adaptáveis e diversos '
                                'entre si, fazendo com que possam escolher '
                                'onde alocar um bônus nas suas Jogadas de '
                                'Proteção. Humanos recebem um bônus de +1 em '
                                'uma única JP à sua escolha.\n',
                 'name': 'Adaptabilidade'}],
  'access': 'complete',
  'alignment_tendency': None,
  'description': 'Com enorme variabilidade cultural e disseminados por todos '
                 'os cantos do mundo, os humanos possuem muita facilidade em '
                 'assumir o lugar central na maioria dos cenários e, quando '
                 'analisados sob essa ótica, revelam sua verdadeira força.\n'
                 '\n'
                 'Você conseguirá encontrar humanos em praticamente todos os '
                 'habitats possíveis, vivendo sob todos os climas, domando o '
                 'ambiente ao seu bel prazer. Eles se adaptam, se moldam e se '
                 'espalham como quase nenhuma outra raça – e fazem isso '
                 'rápido, muito rápido.\n'
                 '\n'
                 'Possuem as mais variadas características físicas, muitos '
                 'tons de cabelo, cores de olhos, pesos e alturas. São '
                 'encontrados dos mais franzinos aos mais brutamontes. Se '
                 'aparentam serem frágeis, com uma vida curta, carecendo de '
                 'poderes ou habilidades especiais, compensam com sua '
                 'capacidade de organização e expansão, que podem ser '
                 'impressionantes.\n'
                 '\n'
                 'Para o padrão dos mundos de fantasia, humanos se reproduzem '
                 'muito rápido. Expandem-se com extrema velocidade, ocupam '
                 'áreas as quais outras raças não conseguem e, por viverem '
                 'pouco se comparados a outras raças, se relacionam com o '
                 'tempo de uma forma totalmente diferente. Durante o período '
                 'da infância de um elfo, um Império humano pode se erguer, '
                 'viver seu apogeu e desaparecer por completo. Acredite, isso '
                 'pode ser assustador para um elfo ou um anão.\n'
                 '\n'
                 'Isso faz com que os humanos sejam a raça padrão dos mundos '
                 'de Fantasia, menos pelo seu poder como indivíduo e muito '
                 'mais pela sua capacidade de se organizar, de assimilar, se '
                 'desenvolver e ocupar.\n'
                 '\n'
                 '# Personalidade\n'
                 '\n'
                 'Como na aparência física, os humanos são diversos e '
                 'versáteis. Sua personalidade é plural. Abraçam todas as '
                 'linhas de pensamento e é difícil estabelecer um padrão de '
                 'pensamento e comportamento quando falamos de humanos.\n'
                 '\n'
                 'Se observados pelo prisma temporal, os humanos são '
                 'ultrarrápidos, pois aprendem técnicas e tecnologias as quais '
                 'avançam e melhoram no espaço de uma única geração. Quando se '
                 'expandem, nunca atacam e fogem em seguida. Sempre dominam, '
                 'se estabelecem, permanecem, colonizam e só vão embora quando '
                 'sua força política e de organização social os impede de '
                 'continuar onde estão.\n'
                 '\n'
                 'Humanos são afeitos a quantidade. Se um elfo leva anos para '
                 'forjar uma cimitarra obra-prima, aplicando técnicas beirando '
                 'o sobrenatural na forja, humanos abraçam a produtividade e '
                 'quantidade.\n'
                 '\n'
                 'Do ponto de vista da pluralidade, apesar de parecer um '
                 'contrassenso, os humanos aceitam bem as diferenças, '
                 'sobretudo se comparados com outras raças. Convivem com '
                 'anões, halflings e elfos, algumas vezes até mesmo até '
                 'assimilando suas colônias, desde que, claro, estes '
                 'estrangeiros não impeçam seus contínuos planos de expansão, '
                 'acúmulo de poder e sobrevivência.\n'
                 '\n'
                 '# O Humano nas Aventuras\n'
                 '\n'
                 'O humano aventureiro é um retrato do humano padrão. '
                 'Adaptável, imaginativo, aguerrido e ambicioso.\n'
                 '\n'
                 'Aventuram-se pelas mais diversas razões – desde para se '
                 'sustentar até para acumular poder, glória ou fama. A ambição '
                 'do humano, por qualquer motivo que seja, é a força motriz a '
                 'qual os tira do conforto de suas choupanas levando-os aos '
                 'túneis escuros dos subterrâneos.\n'
                 '\n'
                 'Eles querem deixar um legado, fazer seu nome famoso, virar '
                 'uma lenda e se tornar um exemplo.\n'
                 '\n'
                 'Humanos aventureiros são orgulhosos por deixarem sua marca '
                 'no mundo.\n'
                 '\n'
                 '## Perguntas para se responder ao criar um humano:\n'
                 '\n'
                 '* **Pergunta 1:** _O que seu humano usa como motivo para '
                 'aventurar-se?_\n'
                 '* **Pergunta 2:** _O que seu humano respeita? O que ele '
                 'busca defender?_\n'
                 '* **Pergunta 3:** _O que seu humano odeia? O que ele deseja '
                 'destruir?_\n',
  'flavor': 'Os mais Comuns, Versáteis e Adaptáveis Aventureiros.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 18},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'id': 'humano',
  'infravision': 0,
  'movement': 9,
  'name': 'Humano',
  'picture': 'https://public.olddragon.com.br/kky9yqsxqgn4pyzvvoxz2twjfeu0',
  'thumb_picture': 'https://public.olddragon.com.br/bzzn9uwm2kskmpvixqbdsyj00cts',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/humano.json'},
 {'access': 'limited',
  'flavor': 'Habitantes das cidades abandonadas e vilas humildes da Britânia '
            'pós-romana.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 59}],
  'id': 'humano-britanico-comum',
  'name': 'Britânico Comum (Humano)',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/humano-britanico-comum.json'},
 {'access': 'limited',
  'flavor': 'Descendentes dos colonizadores romanos, disciplinados e adeptos '
            'do cristianismo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 59}],
  'id': 'humano-britanico-romano',
  'name': 'Britânico Romano (Humano)',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/humano-britanico-romano.json'},
 {'access': 'limited',
  'flavor': 'Habitantes tribais e rurais profundamente ligados às antigas '
            'tradições celtas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 59}],
  'id': 'humano-britanico-rustico',
  'name': 'Britânico Rústico (Humano)',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/humano-britanico-rustico.json'},
 {'access': 'limited',
  'flavor': 'Grandes ferozes bêbados, invasores vindos do continente europeu.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 59}],
  'id': 'humano-franco',
  'name': 'Franco (Humano)',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/humano-franco.json'},
 {'access': 'limited',
  'flavor': 'Guerreiros selvagens e invasores, jamais conquistados pelos '
            'romanos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 59}],
  'id': 'humano-irlandes',
  'name': 'Irlandês (Humano)',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/humano-irlandes.json'},
 {'access': 'limited',
  'flavor': 'Guerreiros exóticos vindos de terras distantes, temidos por sua '
            'aparência imponente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 59}],
  'id': 'humano-numida',
  'name': 'Númida (Humano)',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/humano-numida.json'},
 {'access': 'limited',
  'flavor': 'Invasores ferozes e novos colonizadores da Britânia, marcados '
            'pela guerra e conquista.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 59}],
  'id': 'humano-saxao',
  'name': 'Saxão (Humano)',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/humano-saxao.json'},
 {'abilities': [{'description': 'Meio-elfos compartilham, mesmo parcialmente, '
                                'o aprendizado acelerado dos humanos. Com '
                                'isso, um meio-elfo recebe um bônus de **5% '
                                'sobre** toda experiência (XP) que receber.\n',
                 'name': 'Aprendizado'},
                {'description': 'Os meio-elfos misturam a graciosidade do '
                                'movimento dos elfos com a resistência de um '
                                'corpo mestiço e de origem plural, assim, '
                                'podem escolher entre receber um bônus de +1 '
                                'em uma das duas jogadas de proteção, JPC ou '
                                'JPD.\n',
                 'name': 'Graciosos e Vigorosos'},
                {'description': 'Os meio-elfos recebem um idioma extra '
                                '(escolhido entre o élfico e o idioma falado '
                                'pela sua contraparte humana).\n',
                 'name': 'Idioma Extra'},
                {'description': 'Os meio-elfos são imunes a magias ou efeitos '
                                'que envolvam sono e a paralisação causada por '
                                'um Ghoul.\n',
                 'name': 'Imunidades'}],
  'access': 'complete',
  'alignment_tendency': 'caotico',
  'description': 'Os meio-elfos são o fruto incomum da união entre elfos e '
                 'humanos e, como resultado, acabam sendo vistos com reserva '
                 'entre as duas civilizações.\n'
                 '\n'
                 'Para eles há pouca margem de manobra, sobre onde se colocar. '
                 'Ou se retraem, vivendo à margem de tudo e de todos, ou usam '
                 'sua meia entrada entre humanos e elfos como uma oportunidade '
                 'de se destacar pela interação.\n'
                 '\n'
                 'Meio-elfos estão exatamente no meio do caminho entre homens '
                 'e elfos quando falamos de aparência física.\n'
                 '\n'
                 'São mais franzinos que um homem, com uma compleição física '
                 'mais delicada, mas são sensivelmente mais encorpados e menos '
                 'longilíneos que os elfos.\n'
                 '\n'
                 'Suas feições são ora típicas de uma origem ora de outra. Se '
                 'seus olhos são amendoados e as orelhas levemente mais '
                 'pontudas que o normal, como a dos elfos, também desenvolvem '
                 'barbas e possuem cabelos e olhos mais típicos dos humanos.\n'
                 '\n'
                 'Possuem a versatilidade e a praticidade dos humanos, mas '
                 'mantêm o gosto pelas artes arcanas e a vida silvestre. '
                 'Alguns, principalmente os criados entres os elfos, podem ser '
                 'inclusive xenófobos, repassando aos outros o sentimento de '
                 'segregação que costumam sofrer de seus pares de sangue '
                 'puro.\n'
                 '\n'
                 'Um meio-elfo vive onde seus pais se estabelecem. Se '
                 'crescerem entre os humanos, serão oriundos de cidades ou '
                 'comunidades rurais, mas, se cresceram entre os elfos, '
                 'compartilharão com estes os ambientes florestais, devido a '
                 'ligação da raça com as árvores e a vida silvestre em geral.\n'
                 '\n'
                 'Meio-elfos não criam agrupamentos raciais e não possuem '
                 'cultura própria, visto que vivem entre comunidades élficas e '
                 'humanas.\n'
                 '\n'
                 '# Personalidade\n'
                 '\n'
                 'Sendo sempre muito humano para ser um elfo, e elfo o '
                 'bastante para ser um humano de verdade, essa é a dicotomia '
                 'que um meio-elfo sente desde que passa a se entender como '
                 'gente.\n'
                 '\n'
                 'Mais do que algo que o destaca, é algo que o define. Que faz '
                 'ele ser o que ele é.\n'
                 '\n'
                 'Os efeitos dessa divisão constante na sua cabeça é uma '
                 'personalidade em eterno conflito.\n'
                 '\n'
                 'Ser o que todos gostariam que ele fosse, ou dar vazão àquilo '
                 'que ele sente que é verdadeiramente?\n'
                 '\n'
                 'Ocultar aquilo que não corresponde às expectativas de todos '
                 'ao seu redor ou dar ainda mais destaque e se diferenciar '
                 'dando pouca ou nenhuma atenção ao que todos pensam?\n'
                 '\n'
                 'Boa parte das respostas a estas perguntas provém da sua '
                 'infância. Onde nasceu, onde cresceu, que raça ele teve no '
                 'seu entorno ao ser criado e formar sua personalidade. Este é '
                 'um ótimo ponto de partida para entender um meio-elfo.\n'
                 '\n'
                 '# O Meio-Elfo nas Aventuras\n'
                 '\n'
                 'Se abandonar uma vida pregressa é sempre doloroso, para um '
                 'meio-elfo isso passa a ser uma questão de autoconhecimento. '
                 'Meio-elfos são aventureiros ideais por isso. Partir, para '
                 'meio-elfos, é natural.\n'
                 '\n'
                 'Entender sua outra origem faz parte dessa busca incessante '
                 'de conhecer o mundo. E também é a melhor forma para se '
                 'conectar com uma cultura que faz parte de sua história, mas '
                 'que não esteve presente na sua infância.\n'
                 '\n'
                 'Além disso, há a necessidade de provar-se capaz, para ambos '
                 'os lados, de mostrar que não é um arremedo de duas raças, e '
                 'sim um indivíduo que deve, que pode e que consegue.\n'
                 '\n'
                 'Se entre os elfos tudo muda de forma extremamente devagar, e '
                 'entre humanos a curiosidade pode ser cruel, empunhar uma '
                 'espada num ermo qualquer pode ser o meio ideal de entender '
                 'onde está o seu lugar neste mundo.\n'
                 '\n'
                 '## Perguntas para se responder ao criar um aventureiro '
                 'meio-elfo:\n'
                 '\n'
                 '* **Pergunta 1:** _Onde seu meio-elfo nasceu e cresceu, '
                 'entre os humanos ou entre os elfos?_\n'
                 '* **Pergunta 2:** _Como seu meio-elfo lida com o fato de um '
                 'dos seus pais morrer enquanto você é jovem e o outro morrer '
                 'muito tempo depois?_\n'
                 '* **Pergunta 3:** _O seu meio-elfo acredita pertencer a qual '
                 'lugar?_\n',
  'flavor': 'Metade de dois mundos, sem pertencer a nenhum deles.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 14},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'id': 'meio-elfo',
  'infravision': 9,
  'movement': 9,
  'name': 'Meio-Elfo',
  'picture': 'https://public.olddragon.com.br/axkkol5th5qz71ycer6vtbbv4m9x',
  'thumb_picture': 'https://public.olddragon.com.br/ihon5kbxszkl81qcgt11eodxpvxq',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/meio-elfo.json'},
 {'abilities': [{'description': 'Meio-elfos compartilham, mesmo parcialmente, '
                                'o aprendizado acelerado dos humanos. Com '
                                'isso, um meio-elfo recebe um bônus de **5% '
                                'sobre** toda experiência (XP) que receber.',
                 'name': 'Aprendizado'},
                {'description': 'Os meio-elfos misturam a graciosidade do '
                                'movimento dos elfos com a resistência de um '
                                'corpo mestiço e de origem plural, assim, '
                                'podem escolher entre receber um bônus de +1 '
                                'em uma das duas jogadas de proteção, JPC ou '
                                'JPD.',
                 'name': 'Graciosos e Vigorosos'},
                {'description': 'Os meio-elfos recebem um idioma extra '
                                '(escolhido entre o élfico e o idioma falado '
                                'pela sua contraparte humana).',
                 'name': 'Idioma Extra'},
                {'description': 'Os meio-elfos são imunes a magias ou efeitos '
                                'que envolvam sono e a paralisação causada por '
                                'um Ghoul.',
                 'name': 'Imunidades'},
                {'description': 'Seu sono é agitado e pouco saudável. '
                                'Recuperam apenas metade dos pontos de vida '
                                'devido o descanso, ou levam o dobro de tempo '
                                'para recuperarem pontos de vida perdidos.',
                 'name': 'Sono Atribulado'}],
  'access': 'complete',
  'alignment_tendency': 'caotico',
  'description': 'Inicialmente oriundos de relacionamentos entre humanos e '
                 'povos elfos, os Meio-Elfos se desenvolveram em uma cultura '
                 'própria, com todas as suas peculiaridades.\n'
                 '\n'
                 'A variedade de características físicas dos Meio-Elfos de '
                 'Kadur é impressionante, devido a mistura de suas linhagens '
                 'de origem. Mesmo assim, o Meio-Elfo pode ser melhor descrito '
                 'como um humano, com algumas características físicas élficas. '
                 'Jogue na lista abaixo e determine as características do seu '
                 'Meio-Elfo:\n'
                 '\n'
                 '* **1 chance em 1d6** de possuir os traços faciais '
                 'delicados, finos e graciosos como um elfo;\n'
                 '\n'
                 '* **5 chances em 1d6** de possuir as orelhas longas e '
                 'pontiagudas como um elfo;\n'
                 '\n'
                 '* **4 chances em 1d6** de possuir olhos amendoados e apenas '
                 'levemente alongados;\n'
                 '\n'
                 '* **2 chances em 1d6** de possuir cabelos, barbas e demais '
                 'pelos corporais nas cores típicas dos elfos;\n'
                 '\n'
                 '* **2 chances em 1d6** de possuir cabelos, mas não possuir '
                 'nenhum outro tipo de pelo corporal como os elfos;\n'
                 '\n'
                 '* **3 chances em 1d6** de possuir tamanho, peso e estrutura '
                 'corporal de um elfo; \n'
                 '\n'
                 '* **5 chances em 1d6** de possuir infertilidade total, sendo '
                 'absolutamente incapaz de gerar filhos e descendentes de '
                 'sangue.\n'
                 '\n'
                 '# Personalidade\n'
                 '\n'
                 'Meio-Elfos costumam se tornar adultos próximo aos 30 anos, '
                 'idade esta em que a imensa maioria dos pais humanos já não '
                 'estarão mais vivos, o que acarreta um desenvolvimento '
                 'afetivo precário e mais problemas sociais e psicológicos, os '
                 'tornando órfãos envelhecidos porém ainda totalmente imaturos '
                 'mentalmente.\n'
                 '\n'
                 'Associa-se a isso o fato do Meio-Elfo se considerar um '
                 'estrangeiro em qualquer lugar que esteja, jamais conseguindo '
                 'se inserir por inteiro em qualquer sociedade humana e por se '
                 'achar, dentre outras coisas, incapaz (fruto dos traumas '
                 'devido ao lento desenvolvimento), um pária (Meio-Elfos são '
                 'aberrações aos olhos das culturas humanas), um fugitivo (já '
                 'que a qualquer momento pode ser capturado e vendido aos '
                 'elfos para ser escravizado).\n'
                 '\n'
                 'Essas características reunidas somadas a má formação '
                 'psicológica faz com que os Meio-Elfos desenvolvam durante a '
                 'vida adulta algumas doenças mentais que, se não são '
                 'incapacitantes, os tornarão sofredores por toda a vida.\n'
                 '\n'
                 '# O Meio-Elfo nas Aventuras\n'
                 '\n'
                 'Os Meio-Elfos sofrem de muito preconceito na Era da '
                 'Desolação. Eles sofrem com a desconfiança de todas as demais '
                 'raças de Ryanon, fazendo com que eles sempre se considerem '
                 'estrangeiros em qualquer lugar que estejam.\n'
                 '\n'
                 'Sofrem perseguições diárias e constantemente são traídos. '
                 'Mais do que ninguém precisam escolher a dedo em quem '
                 'confiar, já que sua mania de perseguição não é fruto da sua '
                 'mente, mas infelizmente bem real.\n'
                 '\n'
                 'Assim, a carreira mais atraente para um Meio-Elfo é a de '
                 'Caçador de Recompensas, pois a Licença de Caçador permite, '
                 'na maioria das vezes, que ele possa caminhar livremente em '
                 'regiões dominadas pelas Inquisições das Três Igrejas, sempre '
                 'dispostas a perseguí-los.\n'
                 '\n'
                 '## Perguntas para se responder ao criar um Meio-Elfo:\n'
                 '\n'
                 '* **Pergunta 1:** _Como foi a infância de seu Meio-Elfo? E '
                 'sua relação com os pais?_\n'
                 '* **Pergunta 2:** _Qual o efeito na sua formação de ter sido '
                 'criado com proximidade apenas com uma das raças da sua '
                 'origem?_\n'
                 '* **Pergunta 3:** _O que seu Meio-Elfo pensa do futuro? O '
                 'que ele vislumbra como objetivo?_\n',
  'flavor': 'Os aventureiros desprezados por sua origem e perseguidos pelo que '
            'são.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao.json',
              'page': None},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao-od2.json',
              'page': None}],
  'id': 'meio-elfo-kaduriano',
  'infravision': 9,
  'movement': 9,
  'name': 'Meio-Elfo Kaduriano',
  'picture': 'https://public.olddragon.com.br/1hqdaikzichvn9un90hrzprjuym1',
  'thumb_picture': 'https://public.olddragon.com.br/riyttzg4mzo1txx6leh3q3uth1b8',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/meio-elfo-kaduriano.json'},
 {'abilities': [{'description': 'Tenebruns possuem uma penalidade de 4 em '
                                'qualquer teste de reação que realizem, e por '
                                'serem malquistos e ignorados possuem sempre '
                                'uma chance de 1 em 1d6 de não serem '
                                'percebidos, notados e totalmente ignorados.',
                 'name': 'Pária'},
                {'description': 'Um Tenebrum realiza qualquer ataque com '
                                'adagas ou facas como um ataque fácil, e se '
                                'portarem uma segunda faca ou adaga, recebem '
                                'um bônus de 1 na sua CA exatamente como um '
                                'escudo o faria.',
                 'name': 'Perito em Facas'},
                {'description': 'Tenebruns não se curam naturalmente, nem '
                                'magicamente. No entanto, beber 500ml de '
                                'sangue humano fresco funciona para curar 1d4 '
                                'pontos de vida. Além disso podem repor '
                                'membros perdidos com membros de cadáveres ou '
                                'transferir seus cérebros imortais de corpo '
                                'caso necessário.',
                 'name': 'Cura Impossível'},
                {'description': 'Devida a sua natureza totalmente específica, '
                                'Tenebruns não conseguem conjurar, nem serem '
                                'alvos diretos de magias, sejam estas arcanas '
                                'ou divinas. A explosão de uma bola de fogo '
                                'ainda os afetará, mas uma magia de cura '
                                'jamais fará efeito.',
                 'name': 'Restrições'}],
  'access': 'complete',
  'alignment_tendency': 'neutro',
  'description': 'Criados como uma tentativa de combater o Deus Louco, os '
                 'Tenebruns são fruto de uma expriência macabra que visava '
                 'criar uma espécie de super soldado, usando o sangue de '
                 'marcados, durante as Guerras do Êxodo.\n'
                 '\n'
                 'Depois de várias tentativas e erros, de muitas mortes e '
                 'transformações horrendas, os guerreiros e guerreiras '
                 'selecionados se transformaram nos Tenebruns, super-soldados '
                 'incansáveis, incapazes de sentir dor, e totalmente imunes '
                 'aefeitos mágicos.\n'
                 '\n'
                 'Entretanto, o verdadeiro preço por esses poderes foi '
                 'revelado nas primeiras batalhas contra as forças de Nastur, '
                 'durante as Guerras do Êxodo. Os Tenebruns eram, na '
                 'realidade, uma nova raça de criaturas com almas porém com '
                 'corpos mortos-vivos. Mas apesar dessa natureza sombria, de '
                 'alguma forma a humanidade dos tenebruns foi preservada.\n'
                 '\n'
                 'Fisicamente possuem o mesmo porte físico dos humanos, muito '
                 'embora possuam a pele branca e pálida com cicatrizes '
                 'aparentes e veias escuras e saltadas. Ao redor dos olhos sua '
                 'pele é negra com aspecto esfumaçado, e os cabelos são '
                 'negros, brilhosos e extremamente lisos.\n'
                 '\n'
                 '# Personalidade\n'
                 '\n'
                 'Psicologicamente os Tenebruns são arredios, desconfiados e '
                 'se sentem pouco a vontade perto de estranhos e dificilmente '
                 'fazem amizades, a não ser com outros tenebruns. Preferem '
                 'residir nas grandes cidades humanas onde vivem como cidadãos '
                 'de segunda categoria em guetos próprios ao invés de pequenas '
                 'cidades onde a intolerância frequentemente os coloca em '
                 'situações delicadas.\n'
                 '\n'
                 'O fato de terem de manter seus corpos com a compra de '
                 'cadáveres e partes de corpos, faz com que sejam ainda mais '
                 'marginalizados. Como as compras precisam ser realizadas com '
                 'traficantes de corpos ou lojas do Mercado Negro, isso os '
                 'deixa ainda mais expostos aos rigores da lei e toda a sorte '
                 'de perseguições, assim como a necessidade de beber sangue de '
                 'seres vivos para manterem seus corpos mortos-vivos em '
                 'funcionamento, os tornam sempre suspeitos de serem autores '
                 'de assassinatos misteriosos.\n'
                 '\n'
                 '# O Tenebrum nas Aventuras\n'
                 '\n'
                 'Um Tenebrum é sinal de mau agouro, e constantemente são '
                 'impedidos de entrar em residências, de frequentar tavernas '
                 'ou mesmo caminhar ao lado de um humano.\n'
                 '\n'
                 'A presença de um tenebrum é tão indesejada que eles nem '
                 'sequer são escravizados. Não há mercado para eles.\n'
                 '\n'
                 'Essa condição faz com que a maioria dos tenebruns vivam à '
                 'margem da sociedade, mantendo verdadeiros mercados de órgãos '
                 'e membros humanos clandestinos, profanando sepulturas '
                 'frescas ou mesmo assassinando portadores de corpos frescos '
                 'para se manterem vivos.\n'
                 '\n'
                 'Isso por si só já os coloca em uma posição de desvantagem ao '
                 'se aventurarem. Entretanto, quando conseguem espaço em um '
                 'círculo de aventuras, sua habilidade com facas os tornam '
                 'combatentes perfeitos ou ladrões e assassinos competentes, '
                 'sendo de extrema valia para grupos de aventureiros.\n'
                 '\n'
                 '## Perguntas para se responder ao criar um Tenebrum:\n'
                 '\n'
                 '* **Pergunta 1:** _Como você lida com sua condição bizarra '
                 'de vida?_\n'
                 '* **Pergunta 2:** _Quais as principais sequelas e marcas que '
                 'sua condição de Tenebrum deixou?_\n'
                 '* **Pergunta 3:** _Como que a impossibilidade de ser morto '
                 'se traduz no seu dia a dia?_\n',
  'flavor': 'Os marginalizados aventureiros frutos de experimentos arcanos '
            'horrendos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao.json',
              'page': None},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao-od2.json',
              'page': None}],
  'id': 'tenebrum',
  'infravision': 0,
  'movement': 9,
  'name': 'Tenebrum',
  'picture': 'https://public.olddragon.com.br/orhxm9g7hfzqbjbdzr23mudg74v8',
  'thumb_picture': 'https://public.olddragon.com.br/57rdqpxkxzw7pbngub5q3n4vooj5',
  'type': 'CharacterRace',
  'url': 'https://olddragon.com.br/racas/tenebrum.json'}]



import string
import re
from collections import Counter
from random import choice
from RPG import rolar_dado_notacao, rolar_tabela, d6, d100

from ..helpers import x_em_d6
from ..data import DATA

tesouro_aleatorio = DATA.TESOURO_ALEATORIO
equipamento_raridade = DATA.TESOURO_EQUIPAMENTOS_RARIDADE
equipamento_tipo = DATA.TESOURO_EQUIPAMENTOS
objetos_valor_raridade = DATA.TESOURO_OBJ_VALOR_RARIDADE
objetos_valor_tipo = DATA.TESOURO_OBJ_VALOR
tipos_item = DATA.TESOURO_MAGICO
tesouro_gemas = DATA.TESOURO_GEMA
gemas_qualidade = DATA.TESOURO_GEMA_QUALIDADE

class TesouroAleatorio:
    def __init__(self, tipo_tesouro: str):
        """Gera um tesouro aleatório baseado no tipo, na tabela 9.5.\n
        O tesouro é rolado automaticamente, bastando criar um objeto com a classe,
        mas é possível rolar novamente caso queira rolar mais de um tesouro do mesmo tipo
        através do método .rolar()

        Args:
            tipo_tesouro (str): qual o tipo do tesouro rolado

        Raises:
            ValueError: Levanta um erro no caso do tipo do tesouro não existir

        Returns:
            .tesouro: os dados do tesouro rolado
            .tesouro_rapido: o conteúdo do tesouro rápido
        """

        self._tipo = self._retornar_tipo(tipo_tesouro)
        self._rapido = Counter(self.tabela.get('tesouro_rapido'))
        self._tesouro = {}
        self.rolar()

    def __str__(self):
        texto_final = []

        #* moedas
        pc = self.tesouro.get('pc', 0)
        pp = self.tesouro.get('pp', 0)
        po = self.tesouro.get('po', 0)

        if pc:
            texto_final.append(f'{pc}pc')
        if pp:
            texto_final.append(f'{pp}pp')
        if po:
            texto_final.append(f'{po}po')


        #* gemas
        gemas = self.tesouro.get('gemas').get('descrição') if self.tesouro.get('gemas') else ''
        gemas = f'Gemas: {gemas}' if gemas else ''
        if gemas:
            texto_final.append(gemas)

        #* objetos de valor
        bens = self.tesouro.get('objetos de valor')
        total = sum([bem.get('valor', 0) for bem in bens])
        bens = f'Objetos de valor: {len(bens)} itens no valor total de {total}PO.' if bens else ''
        if bens:
            texto_final.append(bens)

        #* equipamentos
        equipamentos = ', '.join(self.tesouro.get('equipamentos'))
        equipamentos = f'Equipamentos: {equipamentos}.' if equipamentos else ''
        if equipamentos:
            texto_final.append(equipamentos)

        #* itens mágicos
        itens_magicos = [list(item.values())[0] for item in self.tesouro.get('itens mágicos')]
        itens_magicos = ', '.join(itens_magicos)
        itens_magicos = f'Itens mágicos: {itens_magicos}.' if itens_magicos else ''
        if itens_magicos:
            texto_final.append(itens_magicos)

        #* final
        if texto_final:
            texto_final.insert(0, 'Tesouro:')
            return '\n'.join(texto_final)
        else:
            return 'Sem tesouro'
    
    def __repr__(self):
        return f'<TesouroAleatorio(tipo={self.tipo})>'
    
    def __add__(self, other):
        self.tesouro_rapido += other.tesouro_rapido
        self._tesouro['po'] += other._tesouro['po']
        self._tesouro['pp'] += other._tesouro['pp']
        self._tesouro['pc'] += other._tesouro['pc']
        self._tesouro['gemas'] += other._tesouro['gemas']
        self._tesouro['objetos de valor'] += other._tesouro['objetos de valor']
        self._tesouro['equipamentos'] += other._tesouro['equipamentos']
        self._tesouro['valor total'] += other._tesouro['valor total']
        self._tesouro['itens mágicos'] += other._tesouro['itens mágicos']
    

    #? Propriedades
    @property
    def tipo(self):
        return self._tipo

    @tipo.setter
    def tipo(self, tipo_tesouro: str):
        self._tipo = self._retornar_tipo(tipo_tesouro)
        self.rolar()

    @property
    def tabela(self):
        return [i for i in tesouro_aleatorio if i.get('tipo') == self.tipo][0]

    @property
    def tesouro_rapido(self):
        """O tesouro rápido de apenas moedas, pegando a média das chances (primeiro item da tabela 9.5)"""
        return self._rapido

    @tesouro_rapido.setter
    def tesouro_rapido(self, valor: dict | Counter):
        valor = valor if isinstance(valor, Counter) else Counter(valor)
        self._rapido = valor

    @property
    def tesouro(self):
        return self._tesouro
    
    #? Métodos privados
    def _retornar_tipo(self, tipo: str):
        tipo = tipo.upper()

        if tipo not in string.ascii_uppercase[:string.ascii_uppercase.index('V') + 1]:
            raise ValueError(
                f'O tipo "{tipo}" não existe na tabela de tesouro. Escolha entre "A" até "V"')

        return tipo

    def _verificar_se_tem_item(self, tabela: dict):
        return x_em_d6(tabela.get('chance', 0)).sucesso if tabela else False

    def _rolar_quantidade(self, dados: str):
        return rolar_dado_notacao(dados) if isinstance(dados, str) else int(dados)

    def _retornar_lista_bens(self, tabela: str, tabela_raridade: list, tabela_tipo: list):
        base = self.tabela.get(tabela)
        tem_item = self._verificar_se_tem_item(base)
        resultado = []

        if tem_item:
            qtd_itens = base.get('rolamento')
            qtd_itens = self._rolar_quantidade(qtd_itens)

            for _ in range(qtd_itens):
                raridade = rolar_tabela(tabela_raridade, d6(2))
                item = rolar_tabela(tabela_tipo, d6(2), raridade, rolar_dados=True)
                resultado.append(item)

        return resultado

    def _substituir_notacao_dado(self, texto: str):
        regex = r'\d*d\d+(?:[-+*/]\d+)?'
        dado = re.search(regex, texto)
        dado = str(rolar_dado_notacao(dado.group())) if dado else ''

        return re.sub(regex, dado, texto)

    def _retornar_moedas(self, chave: str):
        base = self.tabela.get(chave)
        tem_item_valor = self._verificar_se_tem_item(base)

        if not tem_item_valor:
            return 0
        
        return rolar_dado_notacao(base.get('rolamento'))

    def _retornar_gema(self):
        base = self.tabela.get('gemas')
        tem_gema = self._verificar_se_tem_item(base)

        if tem_gema:
            qtd_gemas = base.get('rolamento')
            qtd_gemas = self._rolar_quantidade(qtd_gemas)

            gema = rolar_tabela(tesouro_gemas, d6(2))
            qualidade = rolar_tabela(gemas_qualidade, d6())
            nome = f'{gema['categoria']} {qualidade['qualidade']}'
            valor = int(gema['valor'] * qualidade['modificador'])
            qtd = f'({qtd_gemas}) ' if qtd_gemas > 1 else ''

            return Counter({
                'categoria': nome,
                'valor': valor,
                'quantidade': qtd_gemas,
                'descrição': f'{qtd}{nome}, valor {valor} PO.'
            })

        return Counter()

    def _retornar_obj_valor(self):
        objetos_valor = self._retornar_lista_bens(
            'objetos_de_valor',
            objetos_valor_raridade, 
            objetos_valor_tipo)
        
        for i, objeto in enumerate(objetos_valor):
            valor = d6(2) * 100
            peso = 1 if objeto[-1] == '*' else 0
            texto = objeto.replace(' *', '')
            objetos_valor[i] = Counter({
                'objeto': texto,
                'valor': valor,
                'carga': peso,
                'descrição': f'{texto}, {valor} PO (carga: {peso})'
            })
        
        return objetos_valor

    def _retornar_equipamentos(self):
        equipamentos = self._retornar_lista_bens(
            'equipamentos',
            equipamento_raridade,
            equipamento_tipo)
        return [self._substituir_notacao_dado(item) for item in equipamentos]

    def _retornar_valor_tesouro(self):
        gemas = self.tesouro.get('gemas')
        valor_gemas = gemas.get('quantidade', 0) * gemas.get('valor', 0)
        valor_bens = sum([item['valor'] for item in self.tesouro.get('objetos de valor')])
        valor_moedas = self.tesouro.get('po') + int(self.tesouro.get('pp') / 10) + int(self.tesouro.get('pc') / 100)

        return valor_gemas + valor_bens + valor_moedas

    def _retorna_itens_magicos(self):
        base = self.tabela.get('itens_magicos')
        tem_item = self._verificar_se_tem_item(base)
        resultado = []

        if tem_item:
            itens = base.get('itens')
            resultado = self._retornar_lista_itens_magicos(itens)

        return resultado

    def _retornar_tesouro(self):
        self._tesouro['po'] = self._retornar_moedas('po')
        self._tesouro['pp'] = self._retornar_moedas('pp')
        self._tesouro['pc'] = self._retornar_moedas('pc')
        self._tesouro['gemas'] = self._retornar_gema()
        self._tesouro['objetos de valor'] = self._retornar_obj_valor()
        self._tesouro['equipamentos'] = self._retornar_equipamentos()
        self._tesouro['valor total'] = self._retornar_valor_tesouro()
        self._tesouro['itens mágicos'] = self._retorna_itens_magicos()

    #? Métodos privados para geração de itens
    def _retornar_lista_itens_magicos(self, itens):
        categoria_itens = Counter({chave: self._rolar_quantidade(qtd) for chave, qtd in itens.items()})
        return self._determinar_tipos_itens(categoria_itens)
    
    def _retornar_tipo_modificador(self, tipo_tesouro: str):
        tipo = rolar_tabela(tipos_item[f'{tipo_tesouro} tipo'], d100())
        mod_magico = rolar_tabela(tipos_item[f'{tipo_tesouro} bônus'], d100())

        return tipo, mod_magico
    
    def _retornar_mod_rolamento_talento(self, mod_magico: str):
        mod_talento = 0

        if '+3' in mod_magico:
            mod_magico = '+3'
            mod_talento = 5
        if '+4' in mod_magico:
            mod_magico = '+4'
            mod_talento = 10
        if '+5' in mod_magico:
            mod_magico = '+5'
            mod_talento = 20

        return mod_magico, mod_talento
    
    def _retornar_talento(self, item, mod_talento, mod_magico):
        talento = rolar_tabela(tipos_item[f'{item} talento'], d100() + mod_talento).lower()
        return '' if talento == 'nenhum talento' or 'amaldiçoad' in mod_magico else f' {talento}'

    def _determinar_tipos_itens(self, categoria_itens: dict):
        resultado = []
        for tipo, qtd in categoria_itens.items():
            for _ in range(qtd):
                resultado.append(tipo)

        tipos = [self._rolar_categoria_tesouro(tipo) for tipo in resultado]
        return [self._rolar_tesouro(item) for item in tipos]
    
    def _rolar_categoria_tesouro(self, tipo: str):
        tabela_base = ['qualquer', 'arma', 'não arma']
        return rolar_tabela(tipos_item[tipo], d100()) if tipo in tabela_base else tipo

    def _rolar_tesouro(self, tipo: str):
        tipos_especiais = ['armadura', 'outra arma', 'espada']

        if tipo in tipos_especiais:
            if tipo == 'armadura':
                item = self._rolar_armaduras()
            if tipo == 'espada':
                item = self._rolar_espada()
            if tipo == 'outra arma':
                item = self._rolar_arma()
        else:
            item = rolar_tabela(tipos_item[tipo], d100())

        return {tipo: item if isinstance(item, str) else choice(item)}

    def _rolar_armaduras(self):
        tipo, mod_magico = self._retornar_tipo_modificador('armadura')
        mod_magico, mod_talento = self._retornar_mod_rolamento_talento(mod_magico)
        talento = self._retornar_talento('armadura', mod_talento, mod_magico)
        
        # ajusta para o masculino
        if tipo in ['escudo']:
            mod_magico = mod_magico.replace('amaldiçoada', 'amaldiçoado')
            talento = talento.replace('curadora', 'curador')

        return f'{tipo} {mod_magico}{talento}'
    
    def _rolar_espada(self):
        tipo, mod_magico = self._retornar_tipo_modificador('espada')
        mod_magico, mod_talento = self._retornar_mod_rolamento_talento(mod_magico)
        talento = self._retornar_talento('espada', mod_talento, mod_magico)

        # ajusta para o masculino
        if tipo.lower() in ['montante']:
            talento = talento.lower().replace('amaldiçoada', 'amaldiçoado')
            talento = talento.lower().replace('matadora', 'matador')
            talento = talento.lower().replace('defensora', 'defensor')
            talento = talento.lower().replace('gélida', 'gélido')

        return f'{tipo} {mod_magico}{talento}'

    def _rolar_arma(self):
        tipo, mod_magico = self._retornar_tipo_modificador('arma')
        mod_magico, mod_talento = self._retornar_mod_rolamento_talento(mod_magico)
        talento = self._retornar_talento('arma', mod_talento, mod_magico)

        # Ajusta mjnições
        qtd = ''
        if 'flecha' in tipo or 'virote' in tipo:
            tipo = choice(tipos_item['tipo flecha'])
            qtd = f' ({rolar_dado_notacao(tipos_item.get('qtd flecha'))})'
        if 'funda' in tipo:
            tipo = 'funda'
            qtd = f' ({rolar_dado_notacao(tipos_item.get('qtd funda'))})'

        # Pega o talento
        talento = choice(tipos_item.get(f'arma talento'))

        # Ajusta o talento matador
        if 'matador' in talento:
            talento += ' ' + choice(tipos_item['talento matador'])


        return f'{tipo}{qtd} {mod_magico}{talento}'


    #? Métodos públicos
    def rolar(self):
        """Rola o tesouro (rolado automaticamente na criação da classe, pode ser rolado novamente)
        """
        self._retornar_tesouro()



from dataclasses import dataclass

from .rolagens import teste_atributo
from .retorna_atributo import retorna_mod_atributo


@dataclass
class AtributoBase:
    valor: int


    #! Métodos
    def rolar(self, modificador: int = 0):
        return teste_atributo(self.valor, modificador)


@dataclass
class Atributo(AtributoBase):
    valor: int
    
    def __post_init__(self):
        self.modificadores = retorna_mod_atributo(self.valor)


    #! Propriedades
    @property
    def modificador(self):
        return self.modificadores.mod
    
    @property
    def circulo_1(self):
        return self.modificadores.circulo_1
    
    @property
    def circulo_2(self):
        return self.modificadores.circulo_2
    
    @property
    def circulo_3(self):
        return self.modificadores.circulo_3
    